==> haskell-vector-algorithms-0.8.0.1-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-algorithms
version: 0.8.0.1
id: vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
key: vector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
license: BSD-3-Clause
copyright: (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
           (c) 2015 Tim Baumann
maintainer: Dan Doel <dan.doel@gmail.com>
            Erik de Castro Lopo <erikd@mega-nerd.com>
author: Dan Doel
homepage: https://github.com/erikd/vector-algorithms/
synopsis: Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.
category: Data
abi: 9960170b43a8c457bb2e739679e8c259
exposed: True
exposed-modules:
    Data.Vector.Algorithms.AmericanFlag Data.Vector.Algorithms.Heap
    Data.Vector.Algorithms.Insertion Data.Vector.Algorithms.Intro
    Data.Vector.Algorithms.Merge Data.Vector.Algorithms.Optimal
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Tim
hidden-modules: Data.Vector.Algorithms.Common
import-dirs: /usr/lib/ghc-8.6.5/site-local/vector-algorithms-0.8.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/vector-algorithms-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vector-algorithms-0.8.0.1
hs-libraries: HSvector-algorithms-0.8.0.1-4s0mIQGU3s1C8KiZioXwL7
include-dirs: /usr/lib/ghc-8.6.5/site-local/vector-algorithms-0.8.0.1/include
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock
haddock-html: /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-algorithms-0.8.0.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-algorithms
version: 0.8.0.3
id: vector-algorithms-0.8.0.3-LaAJv0U2Y86EI0kC0jWQ7E
key: vector-algorithms-0.8.0.3-LaAJv0U2Y86EI0kC0jWQ7E
license: BSD-3-Clause
copyright: (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
           (c) 2015 Tim Baumann
maintainer: Dan Doel <dan.doel@gmail.com>
            Erik de Castro Lopo <erikd@mega-nerd.com>
author: Dan Doel
homepage: https://github.com/erikd/vector-algorithms/
synopsis: Efficient algorithms for vector arrays
description:
    Efficient algorithms for sorting vector arrays. At some stage
    other vector algorithms may be added.
category: Data
abi: f3e15cdde8e845c9925b6d4212a350ed
exposed: True
exposed-modules:
    Data.Vector.Algorithms.AmericanFlag Data.Vector.Algorithms.Heap
    Data.Vector.Algorithms.Insertion Data.Vector.Algorithms.Intro
    Data.Vector.Algorithms.Merge Data.Vector.Algorithms.Optimal
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Tim
hidden-modules: Data.Vector.Algorithms.Common
import-dirs: /usr/lib/ghc-8.6.5/site-local/vector-algorithms-0.8.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/vector-algorithms-0.8.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/vector-algorithms-0.8.0.3
hs-libraries: HSvector-algorithms-0.8.0.3-LaAJv0U2Y86EI0kC0jWQ7E
include-dirs: /usr/lib/ghc-8.6.5/site-local/vector-algorithms-0.8.0.3/include
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock
haddock-html: /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
